==> flutter_catalogue_widgets-0.0.2.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/custom-DetailsCard.dart';
import 'package:flutter_catalogue_widgets/custom-listTile.dart';
import 'package:flutter_catalogue_widgets/custom-textField.dart';
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';


void main() => runApp(MaterialApp(home: BoilerPlate()));

class BoilerPlate extends StatefulWidget {
  @override
  _BoilerPlate createState() => _BoilerPlate();
}

class _BoilerPlate extends State<BoilerPlate> {
  @override
  Widget build(BuildContext context) {
    // Definition goes here
    TextFieldParameters password = new TextFieldParameters(
            decoration: InputDecoration(hintText: 'Password',labelText: 'Password', hintStyle: TextStyle(color: Colors.black), labelStyle: TextStyle(color: Colors.blueGrey),
              prefixIcon: Icon(Icons.lock, color: Colors.black,),
              filled: true, fillColor: Colors.white,
              focusColor: Colors.grey,
              hoverColor: Colors.grey,
              counterText: "",
              border: OutlineInputBorder(
                  borderRadius: BorderRadius.circular(50),
                  borderSide: BorderSide(
                    color: Colors.black)),
          ),
          cursorColor: Colors.black,
          obsecureText: true,
          cursorWidth: 2,
          expands: false,
          maxLines: 1,
          readOnly: false,
          showCursor: true,
          style: TextStyle(color: Colors.black),
          );
    
        List<TileData> listData = [
          TileData(
              leading: Icon(Icons.search),
              title: 'Search',
              subtitle: 'Search Bar',
              enabled: true,
              selected: true),
          TileData(
              leading: Icon(Icons.home),
              title: 'Home',
              subtitle: 'Home Button',
              enabled: true,
              selected: false),
          TileData(
              leading: Icon(Icons.alarm),
              title: 'Clock',
              subtitle: 'Set Alarms',
              enabled: true,
              selected: false)
        ];
        ListTileParameters tileParameters = new ListTileParameters(dense: true, isThreeLine: true);
    
        onListTapped(int index, String title) {
          print(index);
          print(title);
        }
    
        SliderParameters finalObject = new SliderParameters(inactiveColor: Colors.red, label: "Custom Slider", divisions: 3, max: 30, min: 0, activeColor: Colors.pink);
    
        OpportunityDetailsCardData detailsCardData = new OpportunityDetailsCardData(
            height: 250,
            backgroundColor: Colors.red,
            amountTextColor: Colors.red,
            amount: '1000',
            heading: 'Account Name',
            headingValue: 'Main Account',
            subheadingOne: 'Close Date',
            subheadingValueOne: 'Test 1',
            subheadingTwo: 'Type',
            subheadingValueTwo: 'Test 2',
            status: 'Won',
            subheadingIconOne: Icon(Icons.calendar_today),
            subheadingIconTwo: Container(),
            cardWidth: MediaQuery.of(context).size.width);
    cardOnTapped(String heading) {
          print(heading);
        }
    
        return MaterialApp(
          //theme: MediumGreyThemeData(),
          debugShowCheckedModeBanner: false,
          home: Scaffold(
              body: SingleChildScrollView(
                          child: Padding(
            padding: const EdgeInsets.all(10.0),
            child: Column(children: <Widget>[
                SizedBox(height: 30,),
                CustomTextField(params: password,),
                SizedBox(height: 30,),
                Container(color: Colors.white70, child: CustomListTileGeneric(listData, tileParameters, onListTapped)),
                SizedBox(height: 30,),
                SizedBox(height: 30,),
                OpportunityDetailsCard(detailsCardData, cardOnTapped)
    
            ],)
          ),
              ) // Widget Call goes here,,
              ),
        );
      }
    }

==> flutter_catalogue_widgets-0.0.6.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
/* import 'package:flutter_catalogue_widgets/custom-DetailsCard.dart';
import 'package:flutter_catalogue_widgets/custom-listTile.dart';
import 'package:flutter_catalogue_widgets/custom-textField.dart';
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';
 */

void main() {} /* => runApp(MaterialApp(home: BoilerPlate()));

class BoilerPlate extends StatefulWidget {
  @override
  _BoilerPlate createState() => _BoilerPlate();
}

class _BoilerPlate extends State<BoilerPlate> {
  @override
  Widget build(BuildContext context) {
    // Definition goes here
    TextFieldParameters password = new TextFieldParameters(
            decoration: InputDecoration(hintText: 'Password',labelText: 'Password', hintStyle: TextStyle(color: Colors.black), labelStyle: TextStyle(color: Colors.blueGrey),
              prefixIcon: Icon(Icons.lock, color: Colors.black,),
              filled: true, fillColor: Colors.white,
              focusColor: Colors.grey,
              hoverColor: Colors.grey,
              counterText: "",
              border: OutlineInputBorder(
                  borderRadius: BorderRadius.circular(50),
                  borderSide: BorderSide(
                    color: Colors.black)),
          ),
          cursorColor: Colors.black,
          obsecureText: true,
          cursorWidth: 2,
          expands: false,
          maxLines: 1,
          readOnly: false,
          showCursor: true,
          style: TextStyle(color: Colors.black),
          );
    
        List<TileData> listData = [
          TileData(
              leading: Icon(Icons.search),
              title: 'Search',
              subtitle: 'Search Bar',
              enabled: true,
              selected: true),
          TileData(
              leading: Icon(Icons.home),
              title: 'Home',
              subtitle: 'Home Button',
              enabled: true,
              selected: false),
          TileData(
              leading: Icon(Icons.alarm),
              title: 'Clock',
              subtitle: 'Set Alarms',
              enabled: true,
              selected: false)
        ];
        ListTileParameters tileParameters = new ListTileParameters(dense: true, isThreeLine: true);
    
        onListTapped(int index, String title) {
          print(index);
          print(title);
        }
    
        SliderParameters finalObject = new SliderParameters(inactiveColor: Colors.red, label: "Custom Slider", divisions: 3, max: 30, min: 0, activeColor: Colors.pink);
    
        OpportunityDetailsCardData detailsCardData = new OpportunityDetailsCardData(
            height: 250,
            backgroundColor: Colors.red,
            amountTextColor: Colors.red,
            amount: '1000',
            heading: 'Account Name',
            headingValue: 'Main Account',
            subheadingOne: 'Close Date',
            subheadingValueOne: 'Test 1',
            subheadingTwo: 'Type',
            subheadingValueTwo: 'Test 2',
            status: 'Won',
            subheadingIconOne: Icon(Icons.calendar_today),
            subheadingIconTwo: Container(),
            cardWidth: MediaQuery.of(context).size.width);
    cardOnTapped(String heading) {
          print(heading);
        }
    
        return MaterialApp(
          //theme: MediumGreyThemeData(),
          debugShowCheckedModeBanner: false,
          home: Scaffold(
              body: SingleChildScrollView(
                          child: Padding(
            padding: const EdgeInsets.all(10.0),
            child: Column(children: <Widget>[
                SizedBox(height: 30,),
                CustomTextField(params: password,),
                SizedBox(height: 30,),
                Container(color: Colors.white70, child: CustomListTileGeneric(listData, tileParameters, onListTapped)),
                SizedBox(height: 30,),
                SizedBox(height: 30,),
                OpportunityDetailsCard(detailsCardData, cardOnTapped)
    
            ],)
          ),
              ) // Widget Call goes here,,
              ),
        );
      }
    } */
